==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/cognito_user_pool/CognitoUserPoolAdminCreateUserConfig.java <==
package com.hashicorp.cdktf.providers.aws.cognito_user_pool;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:52.211Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.cognitoUserPool.CognitoUserPoolAdminCreateUserConfig")
@software.amazon.jsii.Jsii.Proxy(CognitoUserPoolAdminCreateUserConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CognitoUserPoolAdminCreateUserConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool#allow_admin_create_user_only CognitoUserPool#allow_admin_create_user_only}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAllowAdminCreateUserOnly() {
        return null;
    }

    /**
     * invite_message_template block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool#invite_message_template CognitoUserPool#invite_message_template}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate getInviteMessageTemplate() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CognitoUserPoolAdminCreateUserConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CognitoUserPoolAdminCreateUserConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CognitoUserPoolAdminCreateUserConfig> {
        java.lang.Object allowAdminCreateUserOnly;
        com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate inviteMessageTemplate;

        /**
         * Sets the value of {@link CognitoUserPoolAdminCreateUserConfig#getAllowAdminCreateUserOnly}
         * @param allowAdminCreateUserOnly Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool#allow_admin_create_user_only CognitoUserPool#allow_admin_create_user_only}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowAdminCreateUserOnly(java.lang.Boolean allowAdminCreateUserOnly) {
            this.allowAdminCreateUserOnly = allowAdminCreateUserOnly;
            return this;
        }

        /**
         * Sets the value of {@link CognitoUserPoolAdminCreateUserConfig#getAllowAdminCreateUserOnly}
         * @param allowAdminCreateUserOnly Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool#allow_admin_create_user_only CognitoUserPool#allow_admin_create_user_only}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowAdminCreateUserOnly(com.hashicorp.cdktf.IResolvable allowAdminCreateUserOnly) {
            this.allowAdminCreateUserOnly = allowAdminCreateUserOnly;
            return this;
        }

        /**
         * Sets the value of {@link CognitoUserPoolAdminCreateUserConfig#getInviteMessageTemplate}
         * @param inviteMessageTemplate invite_message_template block.
         *                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool#invite_message_template CognitoUserPool#invite_message_template}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder inviteMessageTemplate(com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate inviteMessageTemplate) {
            this.inviteMessageTemplate = inviteMessageTemplate;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CognitoUserPoolAdminCreateUserConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CognitoUserPoolAdminCreateUserConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CognitoUserPoolAdminCreateUserConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CognitoUserPoolAdminCreateUserConfig {
        private final java.lang.Object allowAdminCreateUserOnly;
        private final com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate inviteMessageTemplate;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.allowAdminCreateUserOnly = software.amazon.jsii.Kernel.get(this, "allowAdminCreateUserOnly", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.inviteMessageTemplate = software.amazon.jsii.Kernel.get(this, "inviteMessageTemplate", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.allowAdminCreateUserOnly = builder.allowAdminCreateUserOnly;
            this.inviteMessageTemplate = builder.inviteMessageTemplate;
        }

        @Override
        public final java.lang.Object getAllowAdminCreateUserOnly() {
            return this.allowAdminCreateUserOnly;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate getInviteMessageTemplate() {
            return this.inviteMessageTemplate;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAllowAdminCreateUserOnly() != null) {
                data.set("allowAdminCreateUserOnly", om.valueToTree(this.getAllowAdminCreateUserOnly()));
            }
            if (this.getInviteMessageTemplate() != null) {
                data.set("inviteMessageTemplate", om.valueToTree(this.getInviteMessageTemplate()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.cognitoUserPool.CognitoUserPoolAdminCreateUserConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CognitoUserPoolAdminCreateUserConfig.Jsii$Proxy that = (CognitoUserPoolAdminCreateUserConfig.Jsii$Proxy) o;

            if (this.allowAdminCreateUserOnly != null ? !this.allowAdminCreateUserOnly.equals(that.allowAdminCreateUserOnly) : that.allowAdminCreateUserOnly != null) return false;
            return this.inviteMessageTemplate != null ? this.inviteMessageTemplate.equals(that.inviteMessageTemplate) : that.inviteMessageTemplate == null;
        }

        @Override
        public final int hashCode() {
            int result = this.allowAdminCreateUserOnly != null ? this.allowAdminCreateUserOnly.hashCode() : 0;
            result = 31 * result + (this.inviteMessageTemplate != null ? this.inviteMessageTemplate.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/cognito_user_pool/CognitoUserPoolAdminCreateUserConfig.java <==
package com.hashicorp.cdktf.providers.aws.cognito_user_pool;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.999Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.cognitoUserPool.CognitoUserPoolAdminCreateUserConfig")
@software.amazon.jsii.Jsii.Proxy(CognitoUserPoolAdminCreateUserConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CognitoUserPoolAdminCreateUserConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/cognito_user_pool#allow_admin_create_user_only CognitoUserPool#allow_admin_create_user_only}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAllowAdminCreateUserOnly() {
        return null;
    }

    /**
     * invite_message_template block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/cognito_user_pool#invite_message_template CognitoUserPool#invite_message_template}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate getInviteMessageTemplate() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CognitoUserPoolAdminCreateUserConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CognitoUserPoolAdminCreateUserConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CognitoUserPoolAdminCreateUserConfig> {
        java.lang.Object allowAdminCreateUserOnly;
        com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate inviteMessageTemplate;

        /**
         * Sets the value of {@link CognitoUserPoolAdminCreateUserConfig#getAllowAdminCreateUserOnly}
         * @param allowAdminCreateUserOnly Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/cognito_user_pool#allow_admin_create_user_only CognitoUserPool#allow_admin_create_user_only}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowAdminCreateUserOnly(java.lang.Boolean allowAdminCreateUserOnly) {
            this.allowAdminCreateUserOnly = allowAdminCreateUserOnly;
            return this;
        }

        /**
         * Sets the value of {@link CognitoUserPoolAdminCreateUserConfig#getAllowAdminCreateUserOnly}
         * @param allowAdminCreateUserOnly Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/cognito_user_pool#allow_admin_create_user_only CognitoUserPool#allow_admin_create_user_only}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowAdminCreateUserOnly(com.hashicorp.cdktf.IResolvable allowAdminCreateUserOnly) {
            this.allowAdminCreateUserOnly = allowAdminCreateUserOnly;
            return this;
        }

        /**
         * Sets the value of {@link CognitoUserPoolAdminCreateUserConfig#getInviteMessageTemplate}
         * @param inviteMessageTemplate invite_message_template block.
         *                              Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/cognito_user_pool#invite_message_template CognitoUserPool#invite_message_template}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder inviteMessageTemplate(com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate inviteMessageTemplate) {
            this.inviteMessageTemplate = inviteMessageTemplate;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CognitoUserPoolAdminCreateUserConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CognitoUserPoolAdminCreateUserConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CognitoUserPoolAdminCreateUserConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CognitoUserPoolAdminCreateUserConfig {
        private final java.lang.Object allowAdminCreateUserOnly;
        private final com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate inviteMessageTemplate;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.allowAdminCreateUserOnly = software.amazon.jsii.Kernel.get(this, "allowAdminCreateUserOnly", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.inviteMessageTemplate = software.amazon.jsii.Kernel.get(this, "inviteMessageTemplate", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.allowAdminCreateUserOnly = builder.allowAdminCreateUserOnly;
            this.inviteMessageTemplate = builder.inviteMessageTemplate;
        }

        @Override
        public final java.lang.Object getAllowAdminCreateUserOnly() {
            return this.allowAdminCreateUserOnly;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.cognito_user_pool.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate getInviteMessageTemplate() {
            return this.inviteMessageTemplate;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAllowAdminCreateUserOnly() != null) {
                data.set("allowAdminCreateUserOnly", om.valueToTree(this.getAllowAdminCreateUserOnly()));
            }
            if (this.getInviteMessageTemplate() != null) {
                data.set("inviteMessageTemplate", om.valueToTree(this.getInviteMessageTemplate()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.cognitoUserPool.CognitoUserPoolAdminCreateUserConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CognitoUserPoolAdminCreateUserConfig.Jsii$Proxy that = (CognitoUserPoolAdminCreateUserConfig.Jsii$Proxy) o;

            if (this.allowAdminCreateUserOnly != null ? !this.allowAdminCreateUserOnly.equals(that.allowAdminCreateUserOnly) : that.allowAdminCreateUserOnly != null) return false;
            return this.inviteMessageTemplate != null ? this.inviteMessageTemplate.equals(that.inviteMessageTemplate) : that.inviteMessageTemplate == null;
        }

        @Override
        public final int hashCode() {
            int result = this.allowAdminCreateUserOnly != null ? this.allowAdminCreateUserOnly.hashCode() : 0;
            result = 31 * result + (this.inviteMessageTemplate != null ? this.inviteMessageTemplate.hashCode() : 0);
            return result;
        }
    }
}
